# The semi-ate-project-database Package

This packages is used for dealing with Semi-ATE Projects. A Semi-ATE project consists of many definitions for describing hardware-setups, masksets, dies, packages, test programs, test flows, single tests and so on. All these definitions are stored in JSON format. To make migration possible. This package is required by the `semi-ate-sammy` package.
